PAWpySeed: projection Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
projection Struct Reference

`#include <utils.h>`

## Public Attributes
int | num_projs
| number of radial projector functions More...
int | total_projs
| number of projector functions More...
int * | ns
| radial projector index More...
int * | ls
| l values of projectors More...
int * | ms
| m values of projectors More...
double complex * | overlaps
| list of <p_i|psi> More...

## Member Data Documentation

int* projection::ls

l values of projectors

int* projection::ms

m values of projectors

int* projection::ns

radial projector index

int projection::num_projs

number of radial projector functions

double complex* projection::overlaps

list of <p_i|psi>

int projection::total_projs

number of projector functions

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h